Ast

Enum Ast 

pub enum Ast<R = TextRange> {
Show 19 variants Mod(Mod<R>), Stmt(Stmt<R>), Expr(Expr<R>), ExprContext(ExprContext), BoolOp(BoolOp), Operator(Operator), UnaryOp(UnaryOp), CmpOp(CmpOp), Comprehension(Comprehension<R>), ExceptHandler(ExceptHandler<R>), Arguments(Arguments<R>), Arg(Arg<R>), Keyword(Keyword<R>), Alias(Alias<R>), WithItem(WithItem<R>), MatchCase(MatchCase<R>), Pattern(Pattern<R>), TypeIgnore(TypeIgnore<R>), TypeParam(TypeParam<R>),
}

Variants



Mod(Mod<R>)



Stmt(Stmt<R>)



Expr(Expr<R>)



ExprContext(ExprContext)



BoolOp(BoolOp)



Operator(Operator)



UnaryOp(UnaryOp)



CmpOp(CmpOp)



Comprehension(Comprehension<R>)



ExceptHandler(ExceptHandler<R>)



Arguments(Arguments<R>)



Arg(Arg<R>)



Keyword(Keyword<R>)



Alias(Alias<R>)



WithItem(WithItem<R>)



MatchCase(MatchCase<R>)



Pattern(Pattern<R>)



TypeIgnore(TypeIgnore<R>)



TypeParam(TypeParam<R>)

Implementations

Source

impl<R> Ast<R>

pub const fn is_module(&self) -> bool

Returns true if self is of variant Mod.

pub fn as_module(&self) -> Option<&Mod<R>>

Returns Some if self is a reference of variant Mod, and None otherwise.

pub fn as_mut_module(&mut self) -> Option<&mut Mod<R>>

Returns Some if self is a mutable reference of variant Mod, and None otherwise.

pub fn expect_module(self) -> Mod<R>
where Self: Debug,

Unwraps the value, yielding the content of Mod.

Panics

Panics if the value is not Mod. In debug builds the panic message includes the content of self.

pub fn module(self) -> Option<Mod<R>>

Returns Some if self is of variant Mod, and None otherwise.

pub const fn is_stmt(&self) -> bool

Returns true if self is of variant Stmt.

pub fn as_stmt(&self) -> Option<&Stmt<R>>

Returns Some if self is a reference of variant Stmt, and None otherwise.

pub fn as_mut_stmt(&mut self) -> Option<&mut Stmt<R>>

Returns Some if self is a mutable reference of variant Stmt, and None otherwise.

pub fn expect_stmt(self) -> Stmt<R>
where Self: Debug,

Unwraps the value, yielding the content of Stmt.

Panics

Panics if the value is not Stmt. In debug builds the panic message includes the content of self.

pub fn stmt(self) -> Option<Stmt<R>>

Returns Some if self is of variant Stmt, and None otherwise.

pub const fn is_expr(&self) -> bool

Returns true if self is of variant Expr.

pub fn as_expr(&self) -> Option<&Expr<R>>

Returns Some if self is a reference of variant Expr, and None otherwise.

pub fn as_mut_expr(&mut self) -> Option<&mut Expr<R>>

Returns Some if self is a mutable reference of variant Expr, and None otherwise.

pub fn expect_expr(self) -> Expr<R>
where Self: Debug,

Unwraps the value, yielding the content of Expr.

Panics

Panics if the value is not Expr. In debug builds the panic message includes the content of self.

pub fn expr(self) -> Option<Expr<R>>

Returns Some if self is of variant Expr, and None otherwise.

pub const fn is_expr_context(&self) -> bool

Returns true if self is of variant ExprContext.

pub fn as_expr_context(&self) -> Option<&ExprContext>

Returns Some if self is a reference of variant ExprContext, and None otherwise.

pub fn as_mut_expr_context(&mut self) -> Option<&mut ExprContext>

Returns Some if self is a mutable reference of variant ExprContext, and None otherwise.

pub fn expect_expr_context(self) -> ExprContext
where Self: Debug,

Unwraps the value, yielding the content of ExprContext.

Panics

Panics if the value is not ExprContext. In debug builds the panic message includes the content of self.

pub fn expr_context(self) -> Option<ExprContext>

Returns Some if self is of variant ExprContext, and None otherwise.

pub const fn is_bool_op(&self) -> bool

Returns true if self is of variant BoolOp.

pub fn as_bool_op(&self) -> Option<&BoolOp>

Returns Some if self is a reference of variant BoolOp, and None otherwise.

pub fn as_mut_bool_op(&mut self) -> Option<&mut BoolOp>

Returns Some if self is a mutable reference of variant BoolOp, and None otherwise.

pub fn expect_bool_op(self) -> BoolOp
where Self: Debug,

Unwraps the value, yielding the content of BoolOp.

Panics

Panics if the value is not BoolOp. In debug builds the panic message includes the content of self.

pub fn bool_op(self) -> Option<BoolOp>

Returns Some if self is of variant BoolOp, and None otherwise.

pub const fn is_operator(&self) -> bool

Returns true if self is of variant Operator.

pub fn as_operator(&self) -> Option<&Operator>

Returns Some if self is a reference of variant Operator, and None otherwise.

pub fn as_mut_operator(&mut self) -> Option<&mut Operator>

Returns Some if self is a mutable reference of variant Operator, and None otherwise.

pub fn expect_operator(self) -> Operator
where Self: Debug,

Unwraps the value, yielding the content of Operator.

Panics

Panics if the value is not Operator. In debug builds the panic message includes the content of self.

pub fn operator(self) -> Option<Operator>

Returns Some if self is of variant Operator, and None otherwise.

pub const fn is_unary_op(&self) -> bool

Returns true if self is of variant UnaryOp.

pub fn as_unary_op(&self) -> Option<&UnaryOp>

Returns Some if self is a reference of variant UnaryOp, and None otherwise.

pub fn as_mut_unary_op(&mut self) -> Option<&mut UnaryOp>

Returns Some if self is a mutable reference of variant UnaryOp, and None otherwise.

pub fn expect_unary_op(self) -> UnaryOp
where Self: Debug,

Unwraps the value, yielding the content of UnaryOp.

Panics

Panics if the value is not UnaryOp. In debug builds the panic message includes the content of self.

pub fn unary_op(self) -> Option<UnaryOp>

Returns Some if self is of variant UnaryOp, and None otherwise.

pub const fn is_cmp_op(&self) -> bool

Returns true if self is of variant CmpOp.

pub fn as_cmp_op(&self) -> Option<&CmpOp>

Returns Some if self is a reference of variant CmpOp, and None otherwise.

pub fn as_mut_cmp_op(&mut self) -> Option<&mut CmpOp>

Returns Some if self is a mutable reference of variant CmpOp, and None otherwise.

pub fn expect_cmp_op(self) -> CmpOp
where Self: Debug,

Unwraps the value, yielding the content of CmpOp.

Panics

Panics if the value is not CmpOp. In debug builds the panic message includes the content of self.

pub fn cmp_op(self) -> Option<CmpOp>

Returns Some if self is of variant CmpOp, and None otherwise.

pub const fn is_comprehension(&self) -> bool

Returns true if self is of variant Comprehension.

pub fn as_comprehension(&self) -> Option<&Comprehension<R>>

Returns Some if self is a reference of variant Comprehension, and None otherwise.

pub fn as_mut_comprehension(&mut self) -> Option<&mut Comprehension<R>>

Returns Some if self is a mutable reference of variant Comprehension, and None otherwise.

pub fn expect_comprehension(self) -> Comprehension<R>
where Self: Debug,

Unwraps the value, yielding the content of Comprehension.

Panics

Panics if the value is not Comprehension. In debug builds the panic message includes the content of self.

pub fn comprehension(self) -> Option<Comprehension<R>>

Returns Some if self is of variant Comprehension, and None otherwise.

pub const fn is_except_handler(&self) -> bool

Returns true if self is of variant ExceptHandler.

pub fn as_except_handler(&self) -> Option<&ExceptHandler<R>>

Returns Some if self is a reference of variant ExceptHandler, and None otherwise.

pub fn as_mut_except_handler(&mut self) -> Option<&mut ExceptHandler<R>>

Returns Some if self is a mutable reference of variant ExceptHandler, and None otherwise.

pub fn expect_except_handler(self) -> ExceptHandler<R>
where Self: Debug,

Unwraps the value, yielding the content of ExceptHandler.

Panics

Panics if the value is not ExceptHandler. In debug builds the panic message includes the content of self.

pub fn except_handler(self) -> Option<ExceptHandler<R>>

Returns Some if self is of variant ExceptHandler, and None otherwise.

pub const fn is_arguments(&self) -> bool

Returns true if self is of variant Arguments.

pub fn as_arguments(&self) -> Option<&Arguments<R>>

Returns Some if self is a reference of variant Arguments, and None otherwise.

pub fn as_mut_arguments(&mut self) -> Option<&mut Arguments<R>>

Returns Some if self is a mutable reference of variant Arguments, and None otherwise.

pub fn expect_arguments(self) -> Arguments<R>
where Self: Debug,

Unwraps the value, yielding the content of Arguments.

Panics

Panics if the value is not Arguments. In debug builds the panic message includes the content of self.

pub fn arguments(self) -> Option<Arguments<R>>

Returns Some if self is of variant Arguments, and None otherwise.

pub const fn is_arg(&self) -> bool

Returns true if self is of variant Arg.

pub fn as_arg(&self) -> Option<&Arg<R>>

Returns Some if self is a reference of variant Arg, and None otherwise.

pub fn as_mut_arg(&mut self) -> Option<&mut Arg<R>>

Returns Some if self is a mutable reference of variant Arg, and None otherwise.

pub fn expect_arg(self) -> Arg<R>
where Self: Debug,

Unwraps the value, yielding the content of Arg.

Panics

Panics if the value is not Arg. In debug builds the panic message includes the content of self.

pub fn arg(self) -> Option<Arg<R>>

Returns Some if self is of variant Arg, and None otherwise.

pub const fn is_keyword(&self) -> bool

Returns true if self is of variant Keyword.

pub fn as_keyword(&self) -> Option<&Keyword<R>>

Returns Some if self is a reference of variant Keyword, and None otherwise.

pub fn as_mut_keyword(&mut self) -> Option<&mut Keyword<R>>

Returns Some if self is a mutable reference of variant Keyword, and None otherwise.

pub fn expect_keyword(self) -> Keyword<R>
where Self: Debug,

Unwraps the value, yielding the content of Keyword.

Panics

Panics if the value is not Keyword. In debug builds the panic message includes the content of self.

pub fn keyword(self) -> Option<Keyword<R>>

Returns Some if self is of variant Keyword, and None otherwise.

pub const fn is_alias(&self) -> bool

Returns true if self is of variant Alias.

pub fn as_alias(&self) -> Option<&Alias<R>>

Returns Some if self is a reference of variant Alias, and None otherwise.

pub fn as_mut_alias(&mut self) -> Option<&mut Alias<R>>

Returns Some if self is a mutable reference of variant Alias, and None otherwise.

pub fn expect_alias(self) -> Alias<R>
where Self: Debug,

Unwraps the value, yielding the content of Alias.

Panics

Panics if the value is not Alias. In debug builds the panic message includes the content of self.

pub fn alias(self) -> Option<Alias<R>>

Returns Some if self is of variant Alias, and None otherwise.

pub const fn is_with_item(&self) -> bool

Returns true if self is of variant WithItem.

pub fn as_with_item(&self) -> Option<&WithItem<R>>

Returns Some if self is a reference of variant WithItem, and None otherwise.

pub fn as_mut_with_item(&mut self) -> Option<&mut WithItem<R>>

Returns Some if self is a mutable reference of variant WithItem, and None otherwise.

pub fn expect_with_item(self) -> WithItem<R>
where Self: Debug,

Unwraps the value, yielding the content of WithItem.

Panics

Panics if the value is not WithItem. In debug builds the panic message includes the content of self.

pub fn with_item(self) -> Option<WithItem<R>>

Returns Some if self is of variant WithItem, and None otherwise.

pub const fn is_match_case(&self) -> bool

Returns true if self is of variant MatchCase.

pub fn as_match_case(&self) -> Option<&MatchCase<R>>

Returns Some if self is a reference of variant MatchCase, and None otherwise.

pub fn as_mut_match_case(&mut self) -> Option<&mut MatchCase<R>>

Returns Some if self is a mutable reference of variant MatchCase, and None otherwise.

pub fn expect_match_case(self) -> MatchCase<R>
where Self: Debug,

Unwraps the value, yielding the content of MatchCase.

Panics

Panics if the value is not MatchCase. In debug builds the panic message includes the content of self.

pub fn match_case(self) -> Option<MatchCase<R>>

Returns Some if self is of variant MatchCase, and None otherwise.

pub const fn is_pattern(&self) -> bool

Returns true if self is of variant Pattern.

pub fn as_pattern(&self) -> Option<&Pattern<R>>

Returns Some if self is a reference of variant Pattern, and None otherwise.

pub fn as_mut_pattern(&mut self) -> Option<&mut Pattern<R>>

Returns Some if self is a mutable reference of variant Pattern, and None otherwise.

pub fn expect_pattern(self) -> Pattern<R>
where Self: Debug,

Unwraps the value, yielding the content of Pattern.

Panics

Panics if the value is not Pattern. In debug builds the panic message includes the content of self.

pub fn pattern(self) -> Option<Pattern<R>>

Returns Some if self is of variant Pattern, and None otherwise.

pub const fn is_type_ignore(&self) -> bool

Returns true if self is of variant TypeIgnore.

pub fn as_type_ignore(&self) -> Option<&TypeIgnore<R>>

Returns Some if self is a reference of variant TypeIgnore, and None otherwise.

pub fn as_mut_type_ignore(&mut self) -> Option<&mut TypeIgnore<R>>

Returns Some if self is a mutable reference of variant TypeIgnore, and None otherwise.

pub fn expect_type_ignore(self) -> TypeIgnore<R>
where Self: Debug,

Unwraps the value, yielding the content of TypeIgnore.

Panics

Panics if the value is not TypeIgnore. In debug builds the panic message includes the content of self.

pub fn type_ignore(self) -> Option<TypeIgnore<R>>

Returns Some if self is of variant TypeIgnore, and None otherwise.

pub const fn is_type_param(&self) -> bool

Returns true if self is of variant TypeParam.

pub fn as_type_param(&self) -> Option<&TypeParam<R>>

Returns Some if self is a reference of variant TypeParam, and None otherwise.

pub fn as_mut_type_param(&mut self) -> Option<&mut TypeParam<R>>

Returns Some if self is a mutable reference of variant TypeParam, and None otherwise.

pub fn expect_type_param(self) -> TypeParam<R>
where Self: Debug,

Unwraps the value, yielding the content of TypeParam.

Panics

Panics if the value is not TypeParam. In debug builds the panic message includes the content of self.

pub fn type_param(self) -> Option<TypeParam<R>>

Returns Some if self is of variant TypeParam, and None otherwise.