Constant

Enum Constant 

pub enum Constant {
    None,
    Bool(bool),
    Str(String),
    Bytes(Vec<u8>),
    Int(BigInt),
    Tuple(Vec<Constant>),
    Float(f64),
    Complex {
        real: f64,
        imag: f64,
    },
    Ellipsis,
}

Variants



None



Bool(bool)



Str(String)



Bytes(Vec<u8>)



Int(BigInt)



Tuple(Vec<Constant>)



Float(f64)



Complex

Fields

real: f64
imag: f64


Ellipsis

Implementations

Source

impl Constant

pub const fn is_none(&self) -> bool

Returns true if self is of variant None.

pub const fn is_bool(&self) -> bool

Returns true if self is of variant Bool.

pub fn as_bool(&self) -> Option<&bool>

Returns Some if self is a reference of variant Bool, and None otherwise.

pub fn as_mut_bool(&mut self) -> Option<&mut bool>

Returns Some if self is a mutable reference of variant Bool, and None otherwise.

pub fn expect_bool(self) -> bool
where Self: Debug,

Unwraps the value, yielding the content of Bool.

Panics

Panics if the value is not Bool. In debug builds the panic message includes the content of self.

pub fn bool(self) -> Option<bool>

Returns Some if self is of variant Bool, and None otherwise.

pub const fn is_str(&self) -> bool

Returns true if self is of variant Str.

pub fn as_str(&self) -> Option<&String>

Returns Some if self is a reference of variant Str, and None otherwise.

pub fn as_mut_str(&mut self) -> Option<&mut String>

Returns Some if self is a mutable reference of variant Str, and None otherwise.

pub fn expect_str(self) -> String
where Self: Debug,

Unwraps the value, yielding the content of Str.

Panics

Panics if the value is not Str. In debug builds the panic message includes the content of self.

pub fn str(self) -> Option<String>

Returns Some if self is of variant Str, and None otherwise.

pub const fn is_bytes(&self) -> bool

Returns true if self is of variant Bytes.

pub fn as_bytes(&self) -> Option<&Vec<u8>>

Returns Some if self is a reference of variant Bytes, and None otherwise.

pub fn as_mut_bytes(&mut self) -> Option<&mut Vec<u8>>

Returns Some if self is a mutable reference of variant Bytes, and None otherwise.

pub fn expect_bytes(self) -> Vec<u8>
where Self: Debug,

Unwraps the value, yielding the content of Bytes.

Panics

Panics if the value is not Bytes. In debug builds the panic message includes the content of self.

pub fn bytes(self) -> Option<Vec<u8>>

Returns Some if self is of variant Bytes, and None otherwise.

pub const fn is_int(&self) -> bool

Returns true if self is of variant Int.

pub fn as_int(&self) -> Option<&BigInt>

Returns Some if self is a reference of variant Int, and None otherwise.

pub fn as_mut_int(&mut self) -> Option<&mut BigInt>

Returns Some if self is a mutable reference of variant Int, and None otherwise.

pub fn expect_int(self) -> BigInt
where Self: Debug,

Unwraps the value, yielding the content of Int.

Panics

Panics if the value is not Int. In debug builds the panic message includes the content of self.

pub fn int(self) -> Option<BigInt>

Returns Some if self is of variant Int, and None otherwise.

pub const fn is_tuple(&self) -> bool

Returns true if self is of variant Tuple.

pub fn as_tuple(&self) -> Option<&Vec<Constant>>

Returns Some if self is a reference of variant Tuple, and None otherwise.

pub fn as_mut_tuple(&mut self) -> Option<&mut Vec<Constant>>

Returns Some if self is a mutable reference of variant Tuple, and None otherwise.

pub fn expect_tuple(self) -> Vec<Constant>
where Self: Debug,

Unwraps the value, yielding the content of Tuple.

Panics

Panics if the value is not Tuple. In debug builds the panic message includes the content of self.

pub fn tuple(self) -> Option<Vec<Constant>>

Returns Some if self is of variant Tuple, and None otherwise.

pub const fn is_float(&self) -> bool

Returns true if self is of variant Float.

pub fn as_float(&self) -> Option<&f64>

Returns Some if self is a reference of variant Float, and None otherwise.

pub fn as_mut_float(&mut self) -> Option<&mut f64>

Returns Some if self is a mutable reference of variant Float, and None otherwise.

pub fn expect_float(self) -> f64
where Self: Debug,

Unwraps the value, yielding the content of Float.

Panics

Panics if the value is not Float. In debug builds the panic message includes the content of self.

pub fn float(self) -> Option<f64>

Returns Some if self is of variant Float, and None otherwise.

pub const fn is_complex(&self) -> bool

Returns true if self is of variant Complex.

pub const fn is_ellipsis(&self) -> bool

Returns true if self is of variant Ellipsis.

Source

impl Constant

pub fn is_true(self) -> bool

pub fn is_false(self) -> bool

pub fn complex(self) -> Option<(f64, f64)>