ExceptHandler

Enum ExceptHandler 

pub enum ExceptHandler<R = TextRange> {
    ExceptHandler(ExceptHandlerExceptHandler<R>),
}
See also excepthandler

Variants

Implementations

Source

impl<R> ExceptHandler<R>

pub const fn is_except_handler(&self) -> bool

Returns true if self is of variant ExceptHandler.

pub fn as_except_handler(&self) -> Option<&ExceptHandlerExceptHandler<R>>

Returns Some if self is a reference of variant ExceptHandler, and None otherwise.

pub fn as_mut_except_handler( &mut self, ) -> Option<&mut ExceptHandlerExceptHandler<R>>

Returns Some if self is a mutable reference of variant ExceptHandler, and None otherwise.

pub fn expect_except_handler(self) -> ExceptHandlerExceptHandler<R>
where Self: Debug,

Unwraps the value, yielding the content of ExceptHandler.

Panics

Panics if the value is not ExceptHandler. In debug builds the panic message includes the content of self.

pub fn except_handler(self) -> Option<ExceptHandlerExceptHandler<R>>

Returns Some if self is of variant ExceptHandler, and None otherwise.