Expr

Enum Expr 

pub enum Expr<R = TextRange> {
Show 27 variants BoolOp(ExprBoolOp<R>), NamedExpr(ExprNamedExpr<R>), BinOp(ExprBinOp<R>), UnaryOp(ExprUnaryOp<R>), Lambda(ExprLambda<R>), IfExp(ExprIfExp<R>), Dict(ExprDict<R>), Set(ExprSet<R>), ListComp(ExprListComp<R>), SetComp(ExprSetComp<R>), DictComp(ExprDictComp<R>), GeneratorExp(ExprGeneratorExp<R>), Await(ExprAwait<R>), Yield(ExprYield<R>), YieldFrom(ExprYieldFrom<R>), Compare(ExprCompare<R>), Call(ExprCall<R>), FormattedValue(ExprFormattedValue<R>), JoinedStr(ExprJoinedStr<R>), Constant(ExprConstant<R>), Attribute(ExprAttribute<R>), Subscript(ExprSubscript<R>), Starred(ExprStarred<R>), Name(ExprName<R>), List(ExprList<R>), Tuple(ExprTuple<R>), Slice(ExprSlice<R>),
}
See also expr

Variants



BoolOp(ExprBoolOp<R>)



NamedExpr(ExprNamedExpr<R>)



BinOp(ExprBinOp<R>)



UnaryOp(ExprUnaryOp<R>)



Lambda(ExprLambda<R>)



IfExp(ExprIfExp<R>)



Dict(ExprDict<R>)



Set(ExprSet<R>)



ListComp(ExprListComp<R>)



SetComp(ExprSetComp<R>)



DictComp(ExprDictComp<R>)



GeneratorExp(ExprGeneratorExp<R>)



Await(ExprAwait<R>)



Yield(ExprYield<R>)



YieldFrom(ExprYieldFrom<R>)



Compare(ExprCompare<R>)



Call(ExprCall<R>)



FormattedValue(ExprFormattedValue<R>)



JoinedStr(ExprJoinedStr<R>)



Constant(ExprConstant<R>)



Attribute(ExprAttribute<R>)



Subscript(ExprSubscript<R>)



Starred(ExprStarred<R>)



Name(ExprName<R>)



List(ExprList<R>)



Tuple(ExprTuple<R>)



Slice(ExprSlice<R>)

Implementations

Source

impl<R> Expr<R>

pub const fn is_bool_op_expr(&self) -> bool

Returns true if self is of variant BoolOp.

pub fn as_bool_op_expr(&self) -> Option<&ExprBoolOp<R>>

Returns Some if self is a reference of variant BoolOp, and None otherwise.

pub fn as_mut_bool_op_expr(&mut self) -> Option<&mut ExprBoolOp<R>>

Returns Some if self is a mutable reference of variant BoolOp, and None otherwise.

pub fn expect_bool_op_expr(self) -> ExprBoolOp<R>
where Self: Debug,

Unwraps the value, yielding the content of BoolOp.

Panics

Panics if the value is not BoolOp. In debug builds the panic message includes the content of self.

pub fn bool_op_expr(self) -> Option<ExprBoolOp<R>>

Returns Some if self is of variant BoolOp, and None otherwise.

pub const fn is_named_expr_expr(&self) -> bool

Returns true if self is of variant NamedExpr.

pub fn as_named_expr_expr(&self) -> Option<&ExprNamedExpr<R>>

Returns Some if self is a reference of variant NamedExpr, and None otherwise.

pub fn as_mut_named_expr_expr(&mut self) -> Option<&mut ExprNamedExpr<R>>

Returns Some if self is a mutable reference of variant NamedExpr, and None otherwise.

pub fn expect_named_expr_expr(self) -> ExprNamedExpr<R>
where Self: Debug,

Unwraps the value, yielding the content of NamedExpr.

Panics

Panics if the value is not NamedExpr. In debug builds the panic message includes the content of self.

pub fn named_expr_expr(self) -> Option<ExprNamedExpr<R>>

Returns Some if self is of variant NamedExpr, and None otherwise.

pub const fn is_bin_op_expr(&self) -> bool

Returns true if self is of variant BinOp.

pub fn as_bin_op_expr(&self) -> Option<&ExprBinOp<R>>

Returns Some if self is a reference of variant BinOp, and None otherwise.

pub fn as_mut_bin_op_expr(&mut self) -> Option<&mut ExprBinOp<R>>

Returns Some if self is a mutable reference of variant BinOp, and None otherwise.

pub fn expect_bin_op_expr(self) -> ExprBinOp<R>
where Self: Debug,

Unwraps the value, yielding the content of BinOp.

Panics

Panics if the value is not BinOp. In debug builds the panic message includes the content of self.

pub fn bin_op_expr(self) -> Option<ExprBinOp<R>>

Returns Some if self is of variant BinOp, and None otherwise.

pub const fn is_unary_op_expr(&self) -> bool

Returns true if self is of variant UnaryOp.

pub fn as_unary_op_expr(&self) -> Option<&ExprUnaryOp<R>>

Returns Some if self is a reference of variant UnaryOp, and None otherwise.

pub fn as_mut_unary_op_expr(&mut self) -> Option<&mut ExprUnaryOp<R>>

Returns Some if self is a mutable reference of variant UnaryOp, and None otherwise.

pub fn expect_unary_op_expr(self) -> ExprUnaryOp<R>
where Self: Debug,

Unwraps the value, yielding the content of UnaryOp.

Panics

Panics if the value is not UnaryOp. In debug builds the panic message includes the content of self.

pub fn unary_op_expr(self) -> Option<ExprUnaryOp<R>>

Returns Some if self is of variant UnaryOp, and None otherwise.

pub const fn is_lambda_expr(&self) -> bool

Returns true if self is of variant Lambda.

pub fn as_lambda_expr(&self) -> Option<&ExprLambda<R>>

Returns Some if self is a reference of variant Lambda, and None otherwise.

pub fn as_mut_lambda_expr(&mut self) -> Option<&mut ExprLambda<R>>

Returns Some if self is a mutable reference of variant Lambda, and None otherwise.

pub fn expect_lambda_expr(self) -> ExprLambda<R>
where Self: Debug,

Unwraps the value, yielding the content of Lambda.

Panics

Panics if the value is not Lambda. In debug builds the panic message includes the content of self.

pub fn lambda_expr(self) -> Option<ExprLambda<R>>

Returns Some if self is of variant Lambda, and None otherwise.

pub const fn is_if_exp_expr(&self) -> bool

Returns true if self is of variant IfExp.

pub fn as_if_exp_expr(&self) -> Option<&ExprIfExp<R>>

Returns Some if self is a reference of variant IfExp, and None otherwise.

pub fn as_mut_if_exp_expr(&mut self) -> Option<&mut ExprIfExp<R>>

Returns Some if self is a mutable reference of variant IfExp, and None otherwise.

pub fn expect_if_exp_expr(self) -> ExprIfExp<R>
where Self: Debug,

Unwraps the value, yielding the content of IfExp.

Panics

Panics if the value is not IfExp. In debug builds the panic message includes the content of self.

pub fn if_exp_expr(self) -> Option<ExprIfExp<R>>

Returns Some if self is of variant IfExp, and None otherwise.

pub const fn is_dict_expr(&self) -> bool

Returns true if self is of variant Dict.

pub fn as_dict_expr(&self) -> Option<&ExprDict<R>>

Returns Some if self is a reference of variant Dict, and None otherwise.

pub fn as_mut_dict_expr(&mut self) -> Option<&mut ExprDict<R>>

Returns Some if self is a mutable reference of variant Dict, and None otherwise.

pub fn expect_dict_expr(self) -> ExprDict<R>
where Self: Debug,

Unwraps the value, yielding the content of Dict.

Panics

Panics if the value is not Dict. In debug builds the panic message includes the content of self.

pub fn dict_expr(self) -> Option<ExprDict<R>>

Returns Some if self is of variant Dict, and None otherwise.

pub const fn is_set_expr(&self) -> bool

Returns true if self is of variant Set.

pub fn as_set_expr(&self) -> Option<&ExprSet<R>>

Returns Some if self is a reference of variant Set, and None otherwise.

pub fn as_mut_set_expr(&mut self) -> Option<&mut ExprSet<R>>

Returns Some if self is a mutable reference of variant Set, and None otherwise.

pub fn expect_set_expr(self) -> ExprSet<R>
where Self: Debug,

Unwraps the value, yielding the content of Set.

Panics

Panics if the value is not Set. In debug builds the panic message includes the content of self.

pub fn set_expr(self) -> Option<ExprSet<R>>

Returns Some if self is of variant Set, and None otherwise.

pub const fn is_list_comp_expr(&self) -> bool

Returns true if self is of variant ListComp.

pub fn as_list_comp_expr(&self) -> Option<&ExprListComp<R>>

Returns Some if self is a reference of variant ListComp, and None otherwise.

pub fn as_mut_list_comp_expr(&mut self) -> Option<&mut ExprListComp<R>>

Returns Some if self is a mutable reference of variant ListComp, and None otherwise.

pub fn expect_list_comp_expr(self) -> ExprListComp<R>
where Self: Debug,

Unwraps the value, yielding the content of ListComp.

Panics

Panics if the value is not ListComp. In debug builds the panic message includes the content of self.

pub fn list_comp_expr(self) -> Option<ExprListComp<R>>

Returns Some if self is of variant ListComp, and None otherwise.

pub const fn is_set_comp_expr(&self) -> bool

Returns true if self is of variant SetComp.

pub fn as_set_comp_expr(&self) -> Option<&ExprSetComp<R>>

Returns Some if self is a reference of variant SetComp, and None otherwise.

pub fn as_mut_set_comp_expr(&mut self) -> Option<&mut ExprSetComp<R>>

Returns Some if self is a mutable reference of variant SetComp, and None otherwise.

pub fn expect_set_comp_expr(self) -> ExprSetComp<R>
where Self: Debug,

Unwraps the value, yielding the content of SetComp.

Panics

Panics if the value is not SetComp. In debug builds the panic message includes the content of self.

pub fn set_comp_expr(self) -> Option<ExprSetComp<R>>

Returns Some if self is of variant SetComp, and None otherwise.

pub const fn is_dict_comp_expr(&self) -> bool

Returns true if self is of variant DictComp.

pub fn as_dict_comp_expr(&self) -> Option<&ExprDictComp<R>>

Returns Some if self is a reference of variant DictComp, and None otherwise.

pub fn as_mut_dict_comp_expr(&mut self) -> Option<&mut ExprDictComp<R>>

Returns Some if self is a mutable reference of variant DictComp, and None otherwise.

pub fn expect_dict_comp_expr(self) -> ExprDictComp<R>
where Self: Debug,

Unwraps the value, yielding the content of DictComp.

Panics

Panics if the value is not DictComp. In debug builds the panic message includes the content of self.

pub fn dict_comp_expr(self) -> Option<ExprDictComp<R>>

Returns Some if self is of variant DictComp, and None otherwise.

pub const fn is_generator_exp_expr(&self) -> bool

Returns true if self is of variant GeneratorExp.

pub fn as_generator_exp_expr(&self) -> Option<&ExprGeneratorExp<R>>

Returns Some if self is a reference of variant GeneratorExp, and None otherwise.

pub fn as_mut_generator_exp_expr(&mut self) -> Option<&mut ExprGeneratorExp<R>>

Returns Some if self is a mutable reference of variant GeneratorExp, and None otherwise.

pub fn expect_generator_exp_expr(self) -> ExprGeneratorExp<R>
where Self: Debug,

Unwraps the value, yielding the content of GeneratorExp.

Panics

Panics if the value is not GeneratorExp. In debug builds the panic message includes the content of self.

pub fn generator_exp_expr(self) -> Option<ExprGeneratorExp<R>>

Returns Some if self is of variant GeneratorExp, and None otherwise.

pub const fn is_await_expr(&self) -> bool

Returns true if self is of variant Await.

pub fn as_await_expr(&self) -> Option<&ExprAwait<R>>

Returns Some if self is a reference of variant Await, and None otherwise.

pub fn as_mut_await_expr(&mut self) -> Option<&mut ExprAwait<R>>

Returns Some if self is a mutable reference of variant Await, and None otherwise.

pub fn expect_await_expr(self) -> ExprAwait<R>
where Self: Debug,

Unwraps the value, yielding the content of Await.

Panics

Panics if the value is not Await. In debug builds the panic message includes the content of self.

pub fn await_expr(self) -> Option<ExprAwait<R>>

Returns Some if self is of variant Await, and None otherwise.

pub const fn is_yield_expr(&self) -> bool

Returns true if self is of variant Yield.

pub fn as_yield_expr(&self) -> Option<&ExprYield<R>>

Returns Some if self is a reference of variant Yield, and None otherwise.

pub fn as_mut_yield_expr(&mut self) -> Option<&mut ExprYield<R>>

Returns Some if self is a mutable reference of variant Yield, and None otherwise.

pub fn expect_yield_expr(self) -> ExprYield<R>
where Self: Debug,

Unwraps the value, yielding the content of Yield.

Panics

Panics if the value is not Yield. In debug builds the panic message includes the content of self.

pub fn yield_expr(self) -> Option<ExprYield<R>>

Returns Some if self is of variant Yield, and None otherwise.

pub const fn is_yield_from_expr(&self) -> bool

Returns true if self is of variant YieldFrom.

pub fn as_yield_from_expr(&self) -> Option<&ExprYieldFrom<R>>

Returns Some if self is a reference of variant YieldFrom, and None otherwise.

pub fn as_mut_yield_from_expr(&mut self) -> Option<&mut ExprYieldFrom<R>>

Returns Some if self is a mutable reference of variant YieldFrom, and None otherwise.

pub fn expect_yield_from_expr(self) -> ExprYieldFrom<R>
where Self: Debug,

Unwraps the value, yielding the content of YieldFrom.

Panics

Panics if the value is not YieldFrom. In debug builds the panic message includes the content of self.

pub fn yield_from_expr(self) -> Option<ExprYieldFrom<R>>

Returns Some if self is of variant YieldFrom, and None otherwise.

pub const fn is_compare_expr(&self) -> bool

Returns true if self is of variant Compare.

pub fn as_compare_expr(&self) -> Option<&ExprCompare<R>>

Returns Some if self is a reference of variant Compare, and None otherwise.

pub fn as_mut_compare_expr(&mut self) -> Option<&mut ExprCompare<R>>

Returns Some if self is a mutable reference of variant Compare, and None otherwise.

pub fn expect_compare_expr(self) -> ExprCompare<R>
where Self: Debug,

Unwraps the value, yielding the content of Compare.

Panics

Panics if the value is not Compare. In debug builds the panic message includes the content of self.

pub fn compare_expr(self) -> Option<ExprCompare<R>>

Returns Some if self is of variant Compare, and None otherwise.

pub const fn is_call_expr(&self) -> bool

Returns true if self is of variant Call.

pub fn as_call_expr(&self) -> Option<&ExprCall<R>>

Returns Some if self is a reference of variant Call, and None otherwise.

pub fn as_mut_call_expr(&mut self) -> Option<&mut ExprCall<R>>

Returns Some if self is a mutable reference of variant Call, and None otherwise.

pub fn expect_call_expr(self) -> ExprCall<R>
where Self: Debug,

Unwraps the value, yielding the content of Call.

Panics

Panics if the value is not Call. In debug builds the panic message includes the content of self.

pub fn call_expr(self) -> Option<ExprCall<R>>

Returns Some if self is of variant Call, and None otherwise.

pub const fn is_formatted_value_expr(&self) -> bool

Returns true if self is of variant FormattedValue.

pub fn as_formatted_value_expr(&self) -> Option<&ExprFormattedValue<R>>

Returns Some if self is a reference of variant FormattedValue, and None otherwise.

pub fn as_mut_formatted_value_expr( &mut self, ) -> Option<&mut ExprFormattedValue<R>>

Returns Some if self is a mutable reference of variant FormattedValue, and None otherwise.

pub fn expect_formatted_value_expr(self) -> ExprFormattedValue<R>
where Self: Debug,

Unwraps the value, yielding the content of FormattedValue.

Panics

Panics if the value is not FormattedValue. In debug builds the panic message includes the content of self.

pub fn formatted_value_expr(self) -> Option<ExprFormattedValue<R>>

Returns Some if self is of variant FormattedValue, and None otherwise.

pub const fn is_joined_str_expr(&self) -> bool

Returns true if self is of variant JoinedStr.

pub fn as_joined_str_expr(&self) -> Option<&ExprJoinedStr<R>>

Returns Some if self is a reference of variant JoinedStr, and None otherwise.

pub fn as_mut_joined_str_expr(&mut self) -> Option<&mut ExprJoinedStr<R>>

Returns Some if self is a mutable reference of variant JoinedStr, and None otherwise.

pub fn expect_joined_str_expr(self) -> ExprJoinedStr<R>
where Self: Debug,

Unwraps the value, yielding the content of JoinedStr.

Panics

Panics if the value is not JoinedStr. In debug builds the panic message includes the content of self.

pub fn joined_str_expr(self) -> Option<ExprJoinedStr<R>>

Returns Some if self is of variant JoinedStr, and None otherwise.

pub const fn is_constant_expr(&self) -> bool

Returns true if self is of variant Constant.

pub fn as_constant_expr(&self) -> Option<&ExprConstant<R>>

Returns Some if self is a reference of variant Constant, and None otherwise.

pub fn as_mut_constant_expr(&mut self) -> Option<&mut ExprConstant<R>>

Returns Some if self is a mutable reference of variant Constant, and None otherwise.

pub fn expect_constant_expr(self) -> ExprConstant<R>
where Self: Debug,

Unwraps the value, yielding the content of Constant.

Panics

Panics if the value is not Constant. In debug builds the panic message includes the content of self.

pub fn constant_expr(self) -> Option<ExprConstant<R>>

Returns Some if self is of variant Constant, and None otherwise.

pub const fn is_attribute_expr(&self) -> bool

Returns true if self is of variant Attribute.

pub fn as_attribute_expr(&self) -> Option<&ExprAttribute<R>>

Returns Some if self is a reference of variant Attribute, and None otherwise.

pub fn as_mut_attribute_expr(&mut self) -> Option<&mut ExprAttribute<R>>

Returns Some if self is a mutable reference of variant Attribute, and None otherwise.

pub fn expect_attribute_expr(self) -> ExprAttribute<R>
where Self: Debug,

Unwraps the value, yielding the content of Attribute.

Panics

Panics if the value is not Attribute. In debug builds the panic message includes the content of self.

pub fn attribute_expr(self) -> Option<ExprAttribute<R>>

Returns Some if self is of variant Attribute, and None otherwise.

pub const fn is_subscript_expr(&self) -> bool

Returns true if self is of variant Subscript.

pub fn as_subscript_expr(&self) -> Option<&ExprSubscript<R>>

Returns Some if self is a reference of variant Subscript, and None otherwise.

pub fn as_mut_subscript_expr(&mut self) -> Option<&mut ExprSubscript<R>>

Returns Some if self is a mutable reference of variant Subscript, and None otherwise.

pub fn expect_subscript_expr(self) -> ExprSubscript<R>
where Self: Debug,

Unwraps the value, yielding the content of Subscript.

Panics

Panics if the value is not Subscript. In debug builds the panic message includes the content of self.

pub fn subscript_expr(self) -> Option<ExprSubscript<R>>

Returns Some if self is of variant Subscript, and None otherwise.

pub const fn is_starred_expr(&self) -> bool

Returns true if self is of variant Starred.

pub fn as_starred_expr(&self) -> Option<&ExprStarred<R>>

Returns Some if self is a reference of variant Starred, and None otherwise.

pub fn as_mut_starred_expr(&mut self) -> Option<&mut ExprStarred<R>>

Returns Some if self is a mutable reference of variant Starred, and None otherwise.

pub fn expect_starred_expr(self) -> ExprStarred<R>
where Self: Debug,

Unwraps the value, yielding the content of Starred.

Panics

Panics if the value is not Starred. In debug builds the panic message includes the content of self.

pub fn starred_expr(self) -> Option<ExprStarred<R>>

Returns Some if self is of variant Starred, and None otherwise.

pub const fn is_name_expr(&self) -> bool

Returns true if self is of variant Name.

pub fn as_name_expr(&self) -> Option<&ExprName<R>>

Returns Some if self is a reference of variant Name, and None otherwise.

pub fn as_mut_name_expr(&mut self) -> Option<&mut ExprName<R>>

Returns Some if self is a mutable reference of variant Name, and None otherwise.

pub fn expect_name_expr(self) -> ExprName<R>
where Self: Debug,

Unwraps the value, yielding the content of Name.

Panics

Panics if the value is not Name. In debug builds the panic message includes the content of self.

pub fn name_expr(self) -> Option<ExprName<R>>

Returns Some if self is of variant Name, and None otherwise.

pub const fn is_list_expr(&self) -> bool

Returns true if self is of variant List.

pub fn as_list_expr(&self) -> Option<&ExprList<R>>

Returns Some if self is a reference of variant List, and None otherwise.

pub fn as_mut_list_expr(&mut self) -> Option<&mut ExprList<R>>

Returns Some if self is a mutable reference of variant List, and None otherwise.

pub fn expect_list_expr(self) -> ExprList<R>
where Self: Debug,

Unwraps the value, yielding the content of List.

Panics

Panics if the value is not List. In debug builds the panic message includes the content of self.

pub fn list_expr(self) -> Option<ExprList<R>>

Returns Some if self is of variant List, and None otherwise.

pub const fn is_tuple_expr(&self) -> bool

Returns true if self is of variant Tuple.

pub fn as_tuple_expr(&self) -> Option<&ExprTuple<R>>

Returns Some if self is a reference of variant Tuple, and None otherwise.

pub fn as_mut_tuple_expr(&mut self) -> Option<&mut ExprTuple<R>>

Returns Some if self is a mutable reference of variant Tuple, and None otherwise.

pub fn expect_tuple_expr(self) -> ExprTuple<R>
where Self: Debug,

Unwraps the value, yielding the content of Tuple.

Panics

Panics if the value is not Tuple. In debug builds the panic message includes the content of self.

pub fn tuple_expr(self) -> Option<ExprTuple<R>>

Returns Some if self is of variant Tuple, and None otherwise.

pub const fn is_slice_expr(&self) -> bool

Returns true if self is of variant Slice.

pub fn as_slice_expr(&self) -> Option<&ExprSlice<R>>

Returns Some if self is a reference of variant Slice, and None otherwise.

pub fn as_mut_slice_expr(&mut self) -> Option<&mut ExprSlice<R>>

Returns Some if self is a mutable reference of variant Slice, and None otherwise.

pub fn expect_slice_expr(self) -> ExprSlice<R>
where Self: Debug,

Unwraps the value, yielding the content of Slice.

Panics

Panics if the value is not Slice. In debug builds the panic message includes the content of self.

pub fn slice_expr(self) -> Option<ExprSlice<R>>

Returns Some if self is of variant Slice, and None otherwise.

Source

impl<R> Expr<R>

pub fn python_name(&self) -> &'static str

Returns a short name for the node suitable for use in error messages.