Mod

Enum Mod 

pub enum Mod<R = TextRange> {
    Module(ModModule<R>),
    Interactive(ModInteractive<R>),
    Expression(ModExpression<R>),
    FunctionType(ModFunctionType<R>),
}
See also mod

Variants



Module(ModModule<R>)



Interactive(ModInteractive<R>)



Expression(ModExpression<R>)



FunctionType(ModFunctionType<R>)

Implementations

Source

impl<R> Mod<R>

pub const fn is_module(&self) -> bool

Returns true if self is of variant Module.

pub fn as_module(&self) -> Option<&ModModule<R>>

Returns Some if self is a reference of variant Module, and None otherwise.

pub fn as_mut_module(&mut self) -> Option<&mut ModModule<R>>

Returns Some if self is a mutable reference of variant Module, and None otherwise.

pub fn expect_module(self) -> ModModule<R>
where Self: Debug,

Unwraps the value, yielding the content of Module.

Panics

Panics if the value is not Module. In debug builds the panic message includes the content of self.

pub fn module(self) -> Option<ModModule<R>>

Returns Some if self is of variant Module, and None otherwise.

pub const fn is_interactive(&self) -> bool

Returns true if self is of variant Interactive.

pub fn as_interactive(&self) -> Option<&ModInteractive<R>>

Returns Some if self is a reference of variant Interactive, and None otherwise.

pub fn as_mut_interactive(&mut self) -> Option<&mut ModInteractive<R>>

Returns Some if self is a mutable reference of variant Interactive, and None otherwise.

pub fn expect_interactive(self) -> ModInteractive<R>
where Self: Debug,

Unwraps the value, yielding the content of Interactive.

Panics

Panics if the value is not Interactive. In debug builds the panic message includes the content of self.

pub fn interactive(self) -> Option<ModInteractive<R>>

Returns Some if self is of variant Interactive, and None otherwise.

pub const fn is_expression(&self) -> bool

Returns true if self is of variant Expression.

pub fn as_expression(&self) -> Option<&ModExpression<R>>

Returns Some if self is a reference of variant Expression, and None otherwise.

pub fn as_mut_expression(&mut self) -> Option<&mut ModExpression<R>>

Returns Some if self is a mutable reference of variant Expression, and None otherwise.

pub fn expect_expression(self) -> ModExpression<R>
where Self: Debug,

Unwraps the value, yielding the content of Expression.

Panics

Panics if the value is not Expression. In debug builds the panic message includes the content of self.

pub fn expression(self) -> Option<ModExpression<R>>

Returns Some if self is of variant Expression, and None otherwise.

pub const fn is_function_type(&self) -> bool

Returns true if self is of variant FunctionType.

pub fn as_function_type(&self) -> Option<&ModFunctionType<R>>

Returns Some if self is a reference of variant FunctionType, and None otherwise.

pub fn as_mut_function_type(&mut self) -> Option<&mut ModFunctionType<R>>

Returns Some if self is a mutable reference of variant FunctionType, and None otherwise.

pub fn expect_function_type(self) -> ModFunctionType<R>
where Self: Debug,

Unwraps the value, yielding the content of FunctionType.

Panics

Panics if the value is not FunctionType. In debug builds the panic message includes the content of self.

pub fn function_type(self) -> Option<ModFunctionType<R>>

Returns Some if self is of variant FunctionType, and None otherwise.