Pattern

Enum Pattern 

pub enum Pattern<R = TextRange> {
    MatchValue(PatternMatchValue<R>),
    MatchSingleton(PatternMatchSingleton<R>),
    MatchSequence(PatternMatchSequence<R>),
    MatchMapping(PatternMatchMapping<R>),
    MatchClass(PatternMatchClass<R>),
    MatchStar(PatternMatchStar<R>),
    MatchAs(PatternMatchAs<R>),
    MatchOr(PatternMatchOr<R>),
}
See also pattern

Variants



MatchValue(PatternMatchValue<R>)



MatchSingleton(PatternMatchSingleton<R>)



MatchSequence(PatternMatchSequence<R>)



MatchMapping(PatternMatchMapping<R>)



MatchClass(PatternMatchClass<R>)



MatchStar(PatternMatchStar<R>)



MatchAs(PatternMatchAs<R>)



MatchOr(PatternMatchOr<R>)

Implementations

Source

impl<R> Pattern<R>

pub const fn is_match_value(&self) -> bool

Returns true if self is of variant MatchValue.

pub fn as_match_value(&self) -> Option<&PatternMatchValue<R>>

Returns Some if self is a reference of variant MatchValue, and None otherwise.

pub fn as_mut_match_value(&mut self) -> Option<&mut PatternMatchValue<R>>

Returns Some if self is a mutable reference of variant MatchValue, and None otherwise.

pub fn expect_match_value(self) -> PatternMatchValue<R>
where Self: Debug,

Unwraps the value, yielding the content of MatchValue.

Panics

Panics if the value is not MatchValue. In debug builds the panic message includes the content of self.

pub fn match_value(self) -> Option<PatternMatchValue<R>>

Returns Some if self is of variant MatchValue, and None otherwise.

pub const fn is_match_singleton(&self) -> bool

Returns true if self is of variant MatchSingleton.

pub fn as_match_singleton(&self) -> Option<&PatternMatchSingleton<R>>

Returns Some if self is a reference of variant MatchSingleton, and None otherwise.

pub fn as_mut_match_singleton( &mut self, ) -> Option<&mut PatternMatchSingleton<R>>

Returns Some if self is a mutable reference of variant MatchSingleton, and None otherwise.

pub fn expect_match_singleton(self) -> PatternMatchSingleton<R>
where Self: Debug,

Unwraps the value, yielding the content of MatchSingleton.

Panics

Panics if the value is not MatchSingleton. In debug builds the panic message includes the content of self.

pub fn match_singleton(self) -> Option<PatternMatchSingleton<R>>

Returns Some if self is of variant MatchSingleton, and None otherwise.

pub const fn is_match_sequence(&self) -> bool

Returns true if self is of variant MatchSequence.

pub fn as_match_sequence(&self) -> Option<&PatternMatchSequence<R>>

Returns Some if self is a reference of variant MatchSequence, and None otherwise.

pub fn as_mut_match_sequence(&mut self) -> Option<&mut PatternMatchSequence<R>>

Returns Some if self is a mutable reference of variant MatchSequence, and None otherwise.

pub fn expect_match_sequence(self) -> PatternMatchSequence<R>
where Self: Debug,

Unwraps the value, yielding the content of MatchSequence.

Panics

Panics if the value is not MatchSequence. In debug builds the panic message includes the content of self.

pub fn match_sequence(self) -> Option<PatternMatchSequence<R>>

Returns Some if self is of variant MatchSequence, and None otherwise.

pub const fn is_match_mapping(&self) -> bool

Returns true if self is of variant MatchMapping.

pub fn as_match_mapping(&self) -> Option<&PatternMatchMapping<R>>

Returns Some if self is a reference of variant MatchMapping, and None otherwise.

pub fn as_mut_match_mapping(&mut self) -> Option<&mut PatternMatchMapping<R>>

Returns Some if self is a mutable reference of variant MatchMapping, and None otherwise.

pub fn expect_match_mapping(self) -> PatternMatchMapping<R>
where Self: Debug,

Unwraps the value, yielding the content of MatchMapping.

Panics

Panics if the value is not MatchMapping. In debug builds the panic message includes the content of self.

pub fn match_mapping(self) -> Option<PatternMatchMapping<R>>

Returns Some if self is of variant MatchMapping, and None otherwise.

pub const fn is_match_class(&self) -> bool

Returns true if self is of variant MatchClass.

pub fn as_match_class(&self) -> Option<&PatternMatchClass<R>>

Returns Some if self is a reference of variant MatchClass, and None otherwise.

pub fn as_mut_match_class(&mut self) -> Option<&mut PatternMatchClass<R>>

Returns Some if self is a mutable reference of variant MatchClass, and None otherwise.

pub fn expect_match_class(self) -> PatternMatchClass<R>
where Self: Debug,

Unwraps the value, yielding the content of MatchClass.

Panics

Panics if the value is not MatchClass. In debug builds the panic message includes the content of self.

pub fn match_class(self) -> Option<PatternMatchClass<R>>

Returns Some if self is of variant MatchClass, and None otherwise.

pub const fn is_match_star(&self) -> bool

Returns true if self is of variant MatchStar.

pub fn as_match_star(&self) -> Option<&PatternMatchStar<R>>

Returns Some if self is a reference of variant MatchStar, and None otherwise.

pub fn as_mut_match_star(&mut self) -> Option<&mut PatternMatchStar<R>>

Returns Some if self is a mutable reference of variant MatchStar, and None otherwise.

pub fn expect_match_star(self) -> PatternMatchStar<R>
where Self: Debug,

Unwraps the value, yielding the content of MatchStar.

Panics

Panics if the value is not MatchStar. In debug builds the panic message includes the content of self.

pub fn match_star(self) -> Option<PatternMatchStar<R>>

Returns Some if self is of variant MatchStar, and None otherwise.

pub const fn is_match_as(&self) -> bool

Returns true if self is of variant MatchAs.

pub fn as_match_as(&self) -> Option<&PatternMatchAs<R>>

Returns Some if self is a reference of variant MatchAs, and None otherwise.

pub fn as_mut_match_as(&mut self) -> Option<&mut PatternMatchAs<R>>

Returns Some if self is a mutable reference of variant MatchAs, and None otherwise.

pub fn expect_match_as(self) -> PatternMatchAs<R>
where Self: Debug,

Unwraps the value, yielding the content of MatchAs.

Panics

Panics if the value is not MatchAs. In debug builds the panic message includes the content of self.

pub fn match_as(self) -> Option<PatternMatchAs<R>>

Returns Some if self is of variant MatchAs, and None otherwise.

pub const fn is_match_or(&self) -> bool

Returns true if self is of variant MatchOr.

pub fn as_match_or(&self) -> Option<&PatternMatchOr<R>>

Returns Some if self is a reference of variant MatchOr, and None otherwise.

pub fn as_mut_match_or(&mut self) -> Option<&mut PatternMatchOr<R>>

Returns Some if self is a mutable reference of variant MatchOr, and None otherwise.

pub fn expect_match_or(self) -> PatternMatchOr<R>
where Self: Debug,

Unwraps the value, yielding the content of MatchOr.

Panics

Panics if the value is not MatchOr. In debug builds the panic message includes the content of self.

pub fn match_or(self) -> Option<PatternMatchOr<R>>

Returns Some if self is of variant MatchOr, and None otherwise.