Stmt

Enum Stmt 

pub enum Stmt<R = TextRange> {
Show 28 variants FunctionDef(StmtFunctionDef<R>), AsyncFunctionDef(StmtAsyncFunctionDef<R>), ClassDef(StmtClassDef<R>), Return(StmtReturn<R>), Delete(StmtDelete<R>), Assign(StmtAssign<R>), TypeAlias(StmtTypeAlias<R>), AugAssign(StmtAugAssign<R>), AnnAssign(StmtAnnAssign<R>), For(StmtFor<R>), AsyncFor(StmtAsyncFor<R>), While(StmtWhile<R>), If(StmtIf<R>), With(StmtWith<R>), AsyncWith(StmtAsyncWith<R>), Match(StmtMatch<R>), Raise(StmtRaise<R>), Try(StmtTry<R>), TryStar(StmtTryStar<R>), Assert(StmtAssert<R>), Import(StmtImport<R>), ImportFrom(StmtImportFrom<R>), Global(StmtGlobal<R>), Nonlocal(StmtNonlocal<R>), Expr(StmtExpr<R>), Pass(StmtPass<R>), Break(StmtBreak<R>), Continue(StmtContinue<R>),
}
See also stmt

Variants



FunctionDef(StmtFunctionDef<R>)



AsyncFunctionDef(StmtAsyncFunctionDef<R>)



ClassDef(StmtClassDef<R>)



Return(StmtReturn<R>)



Delete(StmtDelete<R>)



Assign(StmtAssign<R>)



TypeAlias(StmtTypeAlias<R>)



AugAssign(StmtAugAssign<R>)



AnnAssign(StmtAnnAssign<R>)



For(StmtFor<R>)



AsyncFor(StmtAsyncFor<R>)



While(StmtWhile<R>)



If(StmtIf<R>)



With(StmtWith<R>)



AsyncWith(StmtAsyncWith<R>)



Match(StmtMatch<R>)



Raise(StmtRaise<R>)



Try(StmtTry<R>)



TryStar(StmtTryStar<R>)



Assert(StmtAssert<R>)



Import(StmtImport<R>)



ImportFrom(StmtImportFrom<R>)



Global(StmtGlobal<R>)



Nonlocal(StmtNonlocal<R>)



Expr(StmtExpr<R>)



Pass(StmtPass<R>)



Break(StmtBreak<R>)



Continue(StmtContinue<R>)

Implementations

Source

impl<R> Stmt<R>

pub const fn is_function_def_stmt(&self) -> bool

Returns true if self is of variant FunctionDef.

pub fn as_function_def_stmt(&self) -> Option<&StmtFunctionDef<R>>

Returns Some if self is a reference of variant FunctionDef, and None otherwise.

pub fn as_mut_function_def_stmt(&mut self) -> Option<&mut StmtFunctionDef<R>>

Returns Some if self is a mutable reference of variant FunctionDef, and None otherwise.

pub fn expect_function_def_stmt(self) -> StmtFunctionDef<R>
where Self: Debug,

Unwraps the value, yielding the content of FunctionDef.

Panics

Panics if the value is not FunctionDef. In debug builds the panic message includes the content of self.

pub fn function_def_stmt(self) -> Option<StmtFunctionDef<R>>

Returns Some if self is of variant FunctionDef, and None otherwise.

pub const fn is_async_function_def_stmt(&self) -> bool

Returns true if self is of variant AsyncFunctionDef.

pub fn as_async_function_def_stmt(&self) -> Option<&StmtAsyncFunctionDef<R>>

Returns Some if self is a reference of variant AsyncFunctionDef, and None otherwise.

pub fn as_mut_async_function_def_stmt( &mut self, ) -> Option<&mut StmtAsyncFunctionDef<R>>

Returns Some if self is a mutable reference of variant AsyncFunctionDef, and None otherwise.

pub fn expect_async_function_def_stmt(self) -> StmtAsyncFunctionDef<R>
where Self: Debug,

Unwraps the value, yielding the content of AsyncFunctionDef.

Panics

Panics if the value is not AsyncFunctionDef. In debug builds the panic message includes the content of self.

pub fn async_function_def_stmt(self) -> Option<StmtAsyncFunctionDef<R>>

Returns Some if self is of variant AsyncFunctionDef, and None otherwise.

pub const fn is_class_def_stmt(&self) -> bool

Returns true if self is of variant ClassDef.

pub fn as_class_def_stmt(&self) -> Option<&StmtClassDef<R>>

Returns Some if self is a reference of variant ClassDef, and None otherwise.

pub fn as_mut_class_def_stmt(&mut self) -> Option<&mut StmtClassDef<R>>

Returns Some if self is a mutable reference of variant ClassDef, and None otherwise.

pub fn expect_class_def_stmt(self) -> StmtClassDef<R>
where Self: Debug,

Unwraps the value, yielding the content of ClassDef.

Panics

Panics if the value is not ClassDef. In debug builds the panic message includes the content of self.

pub fn class_def_stmt(self) -> Option<StmtClassDef<R>>

Returns Some if self is of variant ClassDef, and None otherwise.

pub const fn is_return_stmt(&self) -> bool

Returns true if self is of variant Return.

pub fn as_return_stmt(&self) -> Option<&StmtReturn<R>>

Returns Some if self is a reference of variant Return, and None otherwise.

pub fn as_mut_return_stmt(&mut self) -> Option<&mut StmtReturn<R>>

Returns Some if self is a mutable reference of variant Return, and None otherwise.

pub fn expect_return_stmt(self) -> StmtReturn<R>
where Self: Debug,

Unwraps the value, yielding the content of Return.

Panics

Panics if the value is not Return. In debug builds the panic message includes the content of self.

pub fn return_stmt(self) -> Option<StmtReturn<R>>

Returns Some if self is of variant Return, and None otherwise.

pub const fn is_delete_stmt(&self) -> bool

Returns true if self is of variant Delete.

pub fn as_delete_stmt(&self) -> Option<&StmtDelete<R>>

Returns Some if self is a reference of variant Delete, and None otherwise.

pub fn as_mut_delete_stmt(&mut self) -> Option<&mut StmtDelete<R>>

Returns Some if self is a mutable reference of variant Delete, and None otherwise.

pub fn expect_delete_stmt(self) -> StmtDelete<R>
where Self: Debug,

Unwraps the value, yielding the content of Delete.

Panics

Panics if the value is not Delete. In debug builds the panic message includes the content of self.

pub fn delete_stmt(self) -> Option<StmtDelete<R>>

Returns Some if self is of variant Delete, and None otherwise.

pub const fn is_assign_stmt(&self) -> bool

Returns true if self is of variant Assign.

pub fn as_assign_stmt(&self) -> Option<&StmtAssign<R>>

Returns Some if self is a reference of variant Assign, and None otherwise.

pub fn as_mut_assign_stmt(&mut self) -> Option<&mut StmtAssign<R>>

Returns Some if self is a mutable reference of variant Assign, and None otherwise.

pub fn expect_assign_stmt(self) -> StmtAssign<R>
where Self: Debug,

Unwraps the value, yielding the content of Assign.

Panics

Panics if the value is not Assign. In debug builds the panic message includes the content of self.

pub fn assign_stmt(self) -> Option<StmtAssign<R>>

Returns Some if self is of variant Assign, and None otherwise.

pub const fn is_type_alias_stmt(&self) -> bool

Returns true if self is of variant TypeAlias.

pub fn as_type_alias_stmt(&self) -> Option<&StmtTypeAlias<R>>

Returns Some if self is a reference of variant TypeAlias, and None otherwise.

pub fn as_mut_type_alias_stmt(&mut self) -> Option<&mut StmtTypeAlias<R>>

Returns Some if self is a mutable reference of variant TypeAlias, and None otherwise.

pub fn expect_type_alias_stmt(self) -> StmtTypeAlias<R>
where Self: Debug,

Unwraps the value, yielding the content of TypeAlias.

Panics

Panics if the value is not TypeAlias. In debug builds the panic message includes the content of self.

pub fn type_alias_stmt(self) -> Option<StmtTypeAlias<R>>

Returns Some if self is of variant TypeAlias, and None otherwise.

pub const fn is_aug_assign_stmt(&self) -> bool

Returns true if self is of variant AugAssign.

pub fn as_aug_assign_stmt(&self) -> Option<&StmtAugAssign<R>>

Returns Some if self is a reference of variant AugAssign, and None otherwise.

pub fn as_mut_aug_assign_stmt(&mut self) -> Option<&mut StmtAugAssign<R>>

Returns Some if self is a mutable reference of variant AugAssign, and None otherwise.

pub fn expect_aug_assign_stmt(self) -> StmtAugAssign<R>
where Self: Debug,

Unwraps the value, yielding the content of AugAssign.

Panics

Panics if the value is not AugAssign. In debug builds the panic message includes the content of self.

pub fn aug_assign_stmt(self) -> Option<StmtAugAssign<R>>

Returns Some if self is of variant AugAssign, and None otherwise.

pub const fn is_ann_assign_stmt(&self) -> bool

Returns true if self is of variant AnnAssign.

pub fn as_ann_assign_stmt(&self) -> Option<&StmtAnnAssign<R>>

Returns Some if self is a reference of variant AnnAssign, and None otherwise.

pub fn as_mut_ann_assign_stmt(&mut self) -> Option<&mut StmtAnnAssign<R>>

Returns Some if self is a mutable reference of variant AnnAssign, and None otherwise.

pub fn expect_ann_assign_stmt(self) -> StmtAnnAssign<R>
where Self: Debug,

Unwraps the value, yielding the content of AnnAssign.

Panics

Panics if the value is not AnnAssign. In debug builds the panic message includes the content of self.

pub fn ann_assign_stmt(self) -> Option<StmtAnnAssign<R>>

Returns Some if self is of variant AnnAssign, and None otherwise.

pub const fn is_for_stmt(&self) -> bool

Returns true if self is of variant For.

pub fn as_for_stmt(&self) -> Option<&StmtFor<R>>

Returns Some if self is a reference of variant For, and None otherwise.

pub fn as_mut_for_stmt(&mut self) -> Option<&mut StmtFor<R>>

Returns Some if self is a mutable reference of variant For, and None otherwise.

pub fn expect_for_stmt(self) -> StmtFor<R>
where Self: Debug,

Unwraps the value, yielding the content of For.

Panics

Panics if the value is not For. In debug builds the panic message includes the content of self.

pub fn for_stmt(self) -> Option<StmtFor<R>>

Returns Some if self is of variant For, and None otherwise.

pub const fn is_async_for_stmt(&self) -> bool

Returns true if self is of variant AsyncFor.

pub fn as_async_for_stmt(&self) -> Option<&StmtAsyncFor<R>>

Returns Some if self is a reference of variant AsyncFor, and None otherwise.

pub fn as_mut_async_for_stmt(&mut self) -> Option<&mut StmtAsyncFor<R>>

Returns Some if self is a mutable reference of variant AsyncFor, and None otherwise.

pub fn expect_async_for_stmt(self) -> StmtAsyncFor<R>
where Self: Debug,

Unwraps the value, yielding the content of AsyncFor.

Panics

Panics if the value is not AsyncFor. In debug builds the panic message includes the content of self.

pub fn async_for_stmt(self) -> Option<StmtAsyncFor<R>>

Returns Some if self is of variant AsyncFor, and None otherwise.

pub const fn is_while_stmt(&self) -> bool

Returns true if self is of variant While.

pub fn as_while_stmt(&self) -> Option<&StmtWhile<R>>

Returns Some if self is a reference of variant While, and None otherwise.

pub fn as_mut_while_stmt(&mut self) -> Option<&mut StmtWhile<R>>

Returns Some if self is a mutable reference of variant While, and None otherwise.

pub fn expect_while_stmt(self) -> StmtWhile<R>
where Self: Debug,

Unwraps the value, yielding the content of While.

Panics

Panics if the value is not While. In debug builds the panic message includes the content of self.

pub fn while_stmt(self) -> Option<StmtWhile<R>>

Returns Some if self is of variant While, and None otherwise.

pub const fn is_if_stmt(&self) -> bool

Returns true if self is of variant If.

pub fn as_if_stmt(&self) -> Option<&StmtIf<R>>

Returns Some if self is a reference of variant If, and None otherwise.

pub fn as_mut_if_stmt(&mut self) -> Option<&mut StmtIf<R>>

Returns Some if self is a mutable reference of variant If, and None otherwise.

pub fn expect_if_stmt(self) -> StmtIf<R>
where Self: Debug,

Unwraps the value, yielding the content of If.

Panics

Panics if the value is not If. In debug builds the panic message includes the content of self.

pub fn if_stmt(self) -> Option<StmtIf<R>>

Returns Some if self is of variant If, and None otherwise.

pub const fn is_with_stmt(&self) -> bool

Returns true if self is of variant With.

pub fn as_with_stmt(&self) -> Option<&StmtWith<R>>

Returns Some if self is a reference of variant With, and None otherwise.

pub fn as_mut_with_stmt(&mut self) -> Option<&mut StmtWith<R>>

Returns Some if self is a mutable reference of variant With, and None otherwise.

pub fn expect_with_stmt(self) -> StmtWith<R>
where Self: Debug,

Unwraps the value, yielding the content of With.

Panics

Panics if the value is not With. In debug builds the panic message includes the content of self.

pub fn with_stmt(self) -> Option<StmtWith<R>>

Returns Some if self is of variant With, and None otherwise.

pub const fn is_async_with_stmt(&self) -> bool

Returns true if self is of variant AsyncWith.

pub fn as_async_with_stmt(&self) -> Option<&StmtAsyncWith<R>>

Returns Some if self is a reference of variant AsyncWith, and None otherwise.

pub fn as_mut_async_with_stmt(&mut self) -> Option<&mut StmtAsyncWith<R>>

Returns Some if self is a mutable reference of variant AsyncWith, and None otherwise.

pub fn expect_async_with_stmt(self) -> StmtAsyncWith<R>
where Self: Debug,

Unwraps the value, yielding the content of AsyncWith.

Panics

Panics if the value is not AsyncWith. In debug builds the panic message includes the content of self.

pub fn async_with_stmt(self) -> Option<StmtAsyncWith<R>>

Returns Some if self is of variant AsyncWith, and None otherwise.

pub const fn is_match_stmt(&self) -> bool

Returns true if self is of variant Match.

pub fn as_match_stmt(&self) -> Option<&StmtMatch<R>>

Returns Some if self is a reference of variant Match, and None otherwise.

pub fn as_mut_match_stmt(&mut self) -> Option<&mut StmtMatch<R>>

Returns Some if self is a mutable reference of variant Match, and None otherwise.

pub fn expect_match_stmt(self) -> StmtMatch<R>
where Self: Debug,

Unwraps the value, yielding the content of Match.

Panics

Panics if the value is not Match. In debug builds the panic message includes the content of self.

pub fn match_stmt(self) -> Option<StmtMatch<R>>

Returns Some if self is of variant Match, and None otherwise.

pub const fn is_raise_stmt(&self) -> bool

Returns true if self is of variant Raise.

pub fn as_raise_stmt(&self) -> Option<&StmtRaise<R>>

Returns Some if self is a reference of variant Raise, and None otherwise.

pub fn as_mut_raise_stmt(&mut self) -> Option<&mut StmtRaise<R>>

Returns Some if self is a mutable reference of variant Raise, and None otherwise.

pub fn expect_raise_stmt(self) -> StmtRaise<R>
where Self: Debug,

Unwraps the value, yielding the content of Raise.

Panics

Panics if the value is not Raise. In debug builds the panic message includes the content of self.

pub fn raise_stmt(self) -> Option<StmtRaise<R>>

Returns Some if self is of variant Raise, and None otherwise.

pub const fn is_try_stmt(&self) -> bool

Returns true if self is of variant Try.

pub fn as_try_stmt(&self) -> Option<&StmtTry<R>>

Returns Some if self is a reference of variant Try, and None otherwise.

pub fn as_mut_try_stmt(&mut self) -> Option<&mut StmtTry<R>>

Returns Some if self is a mutable reference of variant Try, and None otherwise.

pub fn expect_try_stmt(self) -> StmtTry<R>
where Self: Debug,

Unwraps the value, yielding the content of Try.

Panics

Panics if the value is not Try. In debug builds the panic message includes the content of self.

pub fn try_stmt(self) -> Option<StmtTry<R>>

Returns Some if self is of variant Try, and None otherwise.

pub const fn is_try_star_stmt(&self) -> bool

Returns true if self is of variant TryStar.

pub fn as_try_star_stmt(&self) -> Option<&StmtTryStar<R>>

Returns Some if self is a reference of variant TryStar, and None otherwise.

pub fn as_mut_try_star_stmt(&mut self) -> Option<&mut StmtTryStar<R>>

Returns Some if self is a mutable reference of variant TryStar, and None otherwise.

pub fn expect_try_star_stmt(self) -> StmtTryStar<R>
where Self: Debug,

Unwraps the value, yielding the content of TryStar.

Panics

Panics if the value is not TryStar. In debug builds the panic message includes the content of self.

pub fn try_star_stmt(self) -> Option<StmtTryStar<R>>

Returns Some if self is of variant TryStar, and None otherwise.

pub const fn is_assert_stmt(&self) -> bool

Returns true if self is of variant Assert.

pub fn as_assert_stmt(&self) -> Option<&StmtAssert<R>>

Returns Some if self is a reference of variant Assert, and None otherwise.

pub fn as_mut_assert_stmt(&mut self) -> Option<&mut StmtAssert<R>>

Returns Some if self is a mutable reference of variant Assert, and None otherwise.

pub fn expect_assert_stmt(self) -> StmtAssert<R>
where Self: Debug,

Unwraps the value, yielding the content of Assert.

Panics

Panics if the value is not Assert. In debug builds the panic message includes the content of self.

pub fn assert_stmt(self) -> Option<StmtAssert<R>>

Returns Some if self is of variant Assert, and None otherwise.

pub const fn is_import_stmt(&self) -> bool

Returns true if self is of variant Import.

pub fn as_import_stmt(&self) -> Option<&StmtImport<R>>

Returns Some if self is a reference of variant Import, and None otherwise.

pub fn as_mut_import_stmt(&mut self) -> Option<&mut StmtImport<R>>

Returns Some if self is a mutable reference of variant Import, and None otherwise.

pub fn expect_import_stmt(self) -> StmtImport<R>
where Self: Debug,

Unwraps the value, yielding the content of Import.

Panics

Panics if the value is not Import. In debug builds the panic message includes the content of self.

pub fn import_stmt(self) -> Option<StmtImport<R>>

Returns Some if self is of variant Import, and None otherwise.

pub const fn is_import_from_stmt(&self) -> bool

Returns true if self is of variant ImportFrom.

pub fn as_import_from_stmt(&self) -> Option<&StmtImportFrom<R>>

Returns Some if self is a reference of variant ImportFrom, and None otherwise.

pub fn as_mut_import_from_stmt(&mut self) -> Option<&mut StmtImportFrom<R>>

Returns Some if self is a mutable reference of variant ImportFrom, and None otherwise.

pub fn expect_import_from_stmt(self) -> StmtImportFrom<R>
where Self: Debug,

Unwraps the value, yielding the content of ImportFrom.

Panics

Panics if the value is not ImportFrom. In debug builds the panic message includes the content of self.

pub fn import_from_stmt(self) -> Option<StmtImportFrom<R>>

Returns Some if self is of variant ImportFrom, and None otherwise.

pub const fn is_global_stmt(&self) -> bool

Returns true if self is of variant Global.

pub fn as_global_stmt(&self) -> Option<&StmtGlobal<R>>

Returns Some if self is a reference of variant Global, and None otherwise.

pub fn as_mut_global_stmt(&mut self) -> Option<&mut StmtGlobal<R>>

Returns Some if self is a mutable reference of variant Global, and None otherwise.

pub fn expect_global_stmt(self) -> StmtGlobal<R>
where Self: Debug,

Unwraps the value, yielding the content of Global.

Panics

Panics if the value is not Global. In debug builds the panic message includes the content of self.

pub fn global_stmt(self) -> Option<StmtGlobal<R>>

Returns Some if self is of variant Global, and None otherwise.

pub const fn is_nonlocal_stmt(&self) -> bool

Returns true if self is of variant Nonlocal.

pub fn as_nonlocal_stmt(&self) -> Option<&StmtNonlocal<R>>

Returns Some if self is a reference of variant Nonlocal, and None otherwise.

pub fn as_mut_nonlocal_stmt(&mut self) -> Option<&mut StmtNonlocal<R>>

Returns Some if self is a mutable reference of variant Nonlocal, and None otherwise.

pub fn expect_nonlocal_stmt(self) -> StmtNonlocal<R>
where Self: Debug,

Unwraps the value, yielding the content of Nonlocal.

Panics

Panics if the value is not Nonlocal. In debug builds the panic message includes the content of self.

pub fn nonlocal_stmt(self) -> Option<StmtNonlocal<R>>

Returns Some if self is of variant Nonlocal, and None otherwise.

pub const fn is_expr_stmt(&self) -> bool

Returns true if self is of variant Expr.

pub fn as_expr_stmt(&self) -> Option<&StmtExpr<R>>

Returns Some if self is a reference of variant Expr, and None otherwise.

pub fn as_mut_expr_stmt(&mut self) -> Option<&mut StmtExpr<R>>

Returns Some if self is a mutable reference of variant Expr, and None otherwise.

pub fn expect_expr_stmt(self) -> StmtExpr<R>
where Self: Debug,

Unwraps the value, yielding the content of Expr.

Panics

Panics if the value is not Expr. In debug builds the panic message includes the content of self.

pub fn expr_stmt(self) -> Option<StmtExpr<R>>

Returns Some if self is of variant Expr, and None otherwise.

pub const fn is_pass_stmt(&self) -> bool

Returns true if self is of variant Pass.

pub fn as_pass_stmt(&self) -> Option<&StmtPass<R>>

Returns Some if self is a reference of variant Pass, and None otherwise.

pub fn as_mut_pass_stmt(&mut self) -> Option<&mut StmtPass<R>>

Returns Some if self is a mutable reference of variant Pass, and None otherwise.

pub fn expect_pass_stmt(self) -> StmtPass<R>
where Self: Debug,

Unwraps the value, yielding the content of Pass.

Panics

Panics if the value is not Pass. In debug builds the panic message includes the content of self.

pub fn pass_stmt(self) -> Option<StmtPass<R>>

Returns Some if self is of variant Pass, and None otherwise.

pub const fn is_break_stmt(&self) -> bool

Returns true if self is of variant Break.

pub fn as_break_stmt(&self) -> Option<&StmtBreak<R>>

Returns Some if self is a reference of variant Break, and None otherwise.

pub fn as_mut_break_stmt(&mut self) -> Option<&mut StmtBreak<R>>

Returns Some if self is a mutable reference of variant Break, and None otherwise.

pub fn expect_break_stmt(self) -> StmtBreak<R>
where Self: Debug,

Unwraps the value, yielding the content of Break.

Panics

Panics if the value is not Break. In debug builds the panic message includes the content of self.

pub fn break_stmt(self) -> Option<StmtBreak<R>>

Returns Some if self is of variant Break, and None otherwise.

pub const fn is_continue_stmt(&self) -> bool

Returns true if self is of variant Continue.

pub fn as_continue_stmt(&self) -> Option<&StmtContinue<R>>

Returns Some if self is a reference of variant Continue, and None otherwise.

pub fn as_mut_continue_stmt(&mut self) -> Option<&mut StmtContinue<R>>

Returns Some if self is a mutable reference of variant Continue, and None otherwise.

pub fn expect_continue_stmt(self) -> StmtContinue<R>
where Self: Debug,

Unwraps the value, yielding the content of Continue.

Panics

Panics if the value is not Continue. In debug builds the panic message includes the content of self.

pub fn continue_stmt(self) -> Option<StmtContinue<R>>

Returns Some if self is of variant Continue, and None otherwise.