TypeIgnore

Enum TypeIgnore 

pub enum TypeIgnore<R = TextRange> {
    TypeIgnore(TypeIgnoreTypeIgnore<R>),
}
See also type_ignore

Variants



TypeIgnore(TypeIgnoreTypeIgnore<R>)

Implementations

Source

impl<R> TypeIgnore<R>

pub const fn is_type_ignore(&self) -> bool

Returns true if self is of variant TypeIgnore.

pub fn as_type_ignore(&self) -> Option<&TypeIgnoreTypeIgnore<R>>

Returns Some if self is a reference of variant TypeIgnore, and None otherwise.

pub fn as_mut_type_ignore(&mut self) -> Option<&mut TypeIgnoreTypeIgnore<R>>

Returns Some if self is a mutable reference of variant TypeIgnore, and None otherwise.

pub fn expect_type_ignore(self) -> TypeIgnoreTypeIgnore<R>
where Self: Debug,

Unwraps the value, yielding the content of TypeIgnore.

Panics

Panics if the value is not TypeIgnore. In debug builds the panic message includes the content of self.

pub fn type_ignore(self) -> Option<TypeIgnoreTypeIgnore<R>>

Returns Some if self is of variant TypeIgnore, and None otherwise.