TypeParam

Enum TypeParam 

pub enum TypeParam<R = TextRange> {
    TypeVar(TypeParamTypeVar<R>),
    ParamSpec(TypeParamParamSpec<R>),
    TypeVarTuple(TypeParamTypeVarTuple<R>),
}
See also type_param

Variants



TypeVar(TypeParamTypeVar<R>)



ParamSpec(TypeParamParamSpec<R>)



TypeVarTuple(TypeParamTypeVarTuple<R>)

Implementations

Source

impl<R> TypeParam<R>

pub const fn is_type_var(&self) -> bool

Returns true if self is of variant TypeVar.

pub fn as_type_var(&self) -> Option<&TypeParamTypeVar<R>>

Returns Some if self is a reference of variant TypeVar, and None otherwise.

pub fn as_mut_type_var(&mut self) -> Option<&mut TypeParamTypeVar<R>>

Returns Some if self is a mutable reference of variant TypeVar, and None otherwise.

pub fn expect_type_var(self) -> TypeParamTypeVar<R>
where Self: Debug,

Unwraps the value, yielding the content of TypeVar.

Panics

Panics if the value is not TypeVar. In debug builds the panic message includes the content of self.

pub fn type_var(self) -> Option<TypeParamTypeVar<R>>

Returns Some if self is of variant TypeVar, and None otherwise.

pub const fn is_param_spec(&self) -> bool

Returns true if self is of variant ParamSpec.

pub fn as_param_spec(&self) -> Option<&TypeParamParamSpec<R>>

Returns Some if self is a reference of variant ParamSpec, and None otherwise.

pub fn as_mut_param_spec(&mut self) -> Option<&mut TypeParamParamSpec<R>>

Returns Some if self is a mutable reference of variant ParamSpec, and None otherwise.

pub fn expect_param_spec(self) -> TypeParamParamSpec<R>
where Self: Debug,

Unwraps the value, yielding the content of ParamSpec.

Panics

Panics if the value is not ParamSpec. In debug builds the panic message includes the content of self.

pub fn param_spec(self) -> Option<TypeParamParamSpec<R>>

Returns Some if self is of variant ParamSpec, and None otherwise.

pub const fn is_type_var_tuple(&self) -> bool

Returns true if self is of variant TypeVarTuple.

pub fn as_type_var_tuple(&self) -> Option<&TypeParamTypeVarTuple<R>>

Returns Some if self is a reference of variant TypeVarTuple, and None otherwise.

pub fn as_mut_type_var_tuple(&mut self) -> Option<&mut TypeParamTypeVarTuple<R>>

Returns Some if self is a mutable reference of variant TypeVarTuple, and None otherwise.

pub fn expect_type_var_tuple(self) -> TypeParamTypeVarTuple<R>
where Self: Debug,

Unwraps the value, yielding the content of TypeVarTuple.

Panics

Panics if the value is not TypeVarTuple. In debug builds the panic message includes the content of self.

pub fn type_var_tuple(self) -> Option<TypeParamTypeVarTuple<R>>

Returns Some if self is of variant TypeVarTuple, and None otherwise.